stringtools.arg_to_tridirectional_ordinal_constant
==================================================

.. autofunction:: abjad.tools.stringtools.arg_to_tridirectional_ordinal_constant.arg_to_tridirectional_ordinal_constant
